@@ -7,9 +7,9 @@ from _plotly_utils.utils import PlotlyJSONEncoder
 from .jupyter import register_jupyter
 from .string import task_string_to_context
 
-__author__ = """Brent Baumgartner"""
-__email__ = "brent@twinthread.com"
-__version__ = "0.4.0"
+__author__ = """Brad Johnson"""
+__email__ = "brad.johnson@twinthread.com"
+__version__ = 0.8.9"
 
 import re
 import json
@@ -274,6 +274,27 @@ class TwinThreadClient:
             {**task, "portId": "dataset", "useAttachment": False},
         )
 
+    def _store_trained_model(self, model):
+        import dill
+        self.__trained_model = dill.dumps(model)
+
+    def _get_trained_model_str(self):
+        if not self.__trained_model:
+            return None
+        return self.__trained_model
+
+    def _get_trained_model(self):
+        import dill
+        if not self.__trained_model:
+            return None
+        return dill.loads(self.__trained_model)
+
+    def _register_model_class(self, ModelClass):
+        self.__ModelClass = ModelClass
+
+    def _get_registered_model_class(self):
+        return self.__ModelClass
+
     def _start_run(self, request_id, input_data):
         self.__request_id = request_id
         self.__files = []
@@ -329,13 +350,16 @@ class TwinThreadClient:
 
         from requests_toolbelt import MultipartEncoder
 
+        fields = {
+            "assetModelId": str(self.__context["assetModelId"]),
+            "taskId": str(self.__context["taskId"]),
+            "name": blob_name,
+            "description": name,
+            "file": (blob_name, open(filename, "rb"), "text/csv"),
+        }
+        print(fields)
         m = MultipartEncoder(
-            fields={
-                "assetModelId": str(self.__context["assetModelId"]),
-                "taskId": str(self.__context["taskId"]),
-                "name": blob_name,
-                "file": (blob_name, open(filename, "rb"), "text/csv"),
-            }
+            fields=fields
         )
 
         headers = {
@@ -346,7 +370,6 @@ class TwinThreadClient:
         p = requests.post(
             f"{self.__base_url}/api/Model/ImportTaskData", data=m, headers=headers
         )
-        print(p.status_code)
 
     def save_plotly(self, fig, name=""):
         json = plotlyfig2json(fig)
